# Changelog

## 0.0.1 (2025-02-20)

Full Changelog: [v0.0.1-alpha.0...v0.0.1](https://github.com/Artemis-xyz/artemis/compare/v0.0.1-alpha.0...v0.0.1)

### Chores

* go live ([#3](https://github.com/Artemis-xyz/artemis/issues/3)) ([cd2bb12](https://github.com/Artemis-xyz/artemis/commit/cd2bb129e07fd484bb1af650db44ad9dc1cc4a4a))
* sync repo ([018633f](https://github.com/Artemis-xyz/artemis/commit/018633f7495103403e8504e87204e189012719e1))
* update SDK settings ([#5](https://github.com/Artemis-xyz/artemis/issues/5)) ([e04c2ab](https://github.com/Artemis-xyz/artemis/commit/e04c2ab30fdeb63fd14824aebd67a2054957b430))
